/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.datamodel
 * File:    SearchService.java
 *
 * Copyright (C) 2010-2011 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.datamodel;

import javax.xml.ws.Response;

import org.apache.log4j.Logger;

import de.fhhannover.inform.iron.mapserver.IfmapConstStrings;
import de.fhhannover.inform.iron.mapserver.exceptions.SearchResultsTooBigException;
import de.fhhannover.inform.iron.mapserver.logging.Logging;
import de.fhhannover.inform.iron.mapserver.messages.SearchRequest;
import de.fhhannover.inform.iron.mapserver.messages.SearchResult;

/**
 * This class is a sub service and handles {@link SearchRequest} messages
 * 
 * @author aw
 * @version 0.1
 * 
 * created: 09.12.09
 * changes:
 * 	09.12.09 aw - Created class as singleton and some logic.
 *  04.02.10 aw - added logging with log4j
 *  11.02.10 vp - the visibility of the classes and methods is changed
 *  12.02.10 aw - cleanup and return Value of search changed to Response
 *  30.04.10 aw - remove singletons!
 *  19.08.10 aw - Return a {@link SearchResult} instead of {@link Response}
 *
 */
class SearchService {
	
	private static Logger logger;
	static {
		logger = Logging.getTheLogger();
	}

	private IdentifierRep identifierRep;
	
	private PublisherRep publisherRep;

	
	SearchService(IdentifierRep iRep, PublisherRep pRep) {
		identifierRep = iRep;
		publisherRep = pRep;
	}
	
	/**
	 * Here the search is processed with the help
	 * of a searcher and a builder object who really do the hard work together.
	 * 
	 * @param request
	 * @return
	 * @throws SearchResultsTooBigException 
	 */
	SearchResult search(SearchRequest request) throws SearchResultsTooBigException {
	
		Publisher p = publisherRep.getPublisherBySessionId(request.getSessionId());
		
		logger.trace("searchRequest from " + p.getPublisherId());
		
		SearchResultImpl sRes = new SearchResultImpl();
		SearchResultBuilder builder = new SearchResultBuilderImpl(sRes);
		
		Searcher searcher = new Searcher(identifierRep, request, builder, IfmapConstStrings.SRES_MIN_CNT);
		searcher.runSearch();
		return builder.getResult();
	}
}
 
