/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.datamodel.graph
 * File:    IdentifierWithAdministrativeDomain.java
 *
 * Copyright (C) 2010-2011 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.datamodel.graph;

import de.fhhannover.inform.iron.mapserver.IfmapConstStrings;
import de.fhhannover.inform.iron.mapserver.datamodel.DataModelService;
import de.fhhannover.inform.iron.mapserver.provider.DataModelServerConfigurationProvider;

/**
 * Identifier which contains a administrative Domain
 * 
 * This class extends Identifier to contain the field
 * administrativeDomain which part of the identifier
 * uses
 * 
 * @author awe
 * @version 0.1
 * 
 * created: 26.11.09
 * changes:
 *  26.11.09 aw - Created first version of this class
 *  28.11.09 aw - Implemented equals() to compare the administrativeDomain
 *  	attribute. (in favor of the compareAdministrativeDomain() method)
 *  09.12.09 aw - added copy constructor
 *  17.12.09 aw - added type
 *  12.02.10 aw - removed some unused code
 */
abstract public class IdentifierWithAdministrativeDomain extends Identifier {
	
	private final String administrativeDomain;
	private final int hashCode;
	
	/**
	 * The bytes used for the administrativeDomain attribute, if at all
	 */
	private final int admByteCount;
	
	
	public IdentifierWithAdministrativeDomain(final IdentifierType type, String ad) {
		super(type);
		if (ad == null)
			ad = "";
		administrativeDomain = ad;
		hashCode = (super.hashCode() + administrativeDomain).hashCode();
		
		if (ad.length() == 0) {
			admByteCount = 0;
		} else {
			admByteCount = IfmapConstStrings.ADMDOM_CNT + ad.length();
		}
	}
	
	public String getAdministrativeDomain() {
		return administrativeDomain;
	}
	
	public boolean equals(Object o) {
		IdentifierWithAdministrativeDomain oident;
		String oad;
		DataModelServerConfigurationProvider servConf;
			
		
		if (o == null)
			return false;
		
		if(this == o) 
			return true;
		
		if (o instanceof IdentifierWithAdministrativeDomain) {
			oident = (IdentifierWithAdministrativeDomain) o;
			oad = oident.getAdministrativeDomain();
			servConf = DataModelService.getServerConfiguration();
			
			if (servConf.getAdministrativeDomainIsCaseSensitive()) {
				return administrativeDomain.equals(oad);
			} else {
				return administrativeDomain.equalsIgnoreCase(oad);
			}
		}
		return false;
	}
	
	public int hashCode() {
		return hashCode;
	}

	/**
	 * @return the number of bytes needed to represent the administrativeDomain
	 *         attribute, or zero if none is set.
	 */
	public int getAdministrativeDomainByteCount() {
		return admByteCount;
	}
}
