/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.messages
 * File:    PollResult.java
 *
 * Copyright (C) 2010-2011 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.messages;

import java.util.ArrayList;
import java.util.List;

/**
 * A {@link PollResult} represents a message which is sent to a MAPC in response
 * to a poll call. However, the message which is sent on the network might differ,
 * for example the {@link PollResult} could be split up in shorter messages.
 * 
 * A poll result contains:
 *  - all search results for all subscriptions of this MAPC if those are not
 *    empty
 *  - all update results ... [see above] ...
 *  - all delete results ... [see above] ...
 *  - all notify results ... [see above] ...
 *  
 *  TODO: This maybe should just be an interface, similar to {@link SearchResult},
 *  and implemented somewhere in the datamodel package.
 * 
 * 
 * @version 0.1
 * @author aw
 */

/*
 * created: 01.05.10 aw
 * changes:
 *  01.05.10 aw - created empty class
 *	15.05.10 vp - fixed incorrect if...
 *  08.06.10 aw - some comments
 */
public class PollResult {
	
	private List<SearchResult> searchResults;
	private List<SearchResult> updateResults;
	private List<SearchResult> deleteResults;
	private List<SearchResult> notifyResults;
	private List<String> errorResults;

	public PollResult(List<SearchResult> searchR, List<SearchResult> updateR,
			List<SearchResult> deleteR, List<SearchResult> notifyR,
			List<String> errR) {
		
		if (errR == null
				&& searchR == null
				&& updateR == null
				&& deleteR == null
				&& notifyR == null)
			throw new RuntimeException("At least one result needs to be set");
		
		if (searchR == null) {
			searchR = new ArrayList<SearchResult>();
		}
		
		if (updateR == null) {
			updateR = new ArrayList<SearchResult>();
		}
		
		if (deleteR == null) {
			deleteR = new ArrayList<SearchResult>();
		}
		
		if (notifyR == null) {
			notifyR = new ArrayList<SearchResult>();
		}
		
		if (errR == null) {
			errR = new ArrayList<String>();
		}
		
		searchResults = searchR;
		updateResults = updateR;
		deleteResults = deleteR;
		notifyResults = notifyR;
		errorResults = errR;
	}

	public List<SearchResult> getSearchResults() {
		return searchResults;
	}

	public List<SearchResult> getUpdateResults() {
		return updateResults;
	}

	public List<SearchResult> getDeleteResults() {
		return deleteResults;
	}

	public List<SearchResult> getNotifyResults() {
		return notifyResults;
	}

	public List<String> getErrorResults() {
		return errorResults;
	}
}
